/**
 * PIC18F Minimal SPI master example, tested on an EasyPIC3 with a PIC18F458
 * sending data to an EasyPIC Fusion v8 with a PIC32MX795F512L
 *
 * Compiler versions tested:
 *   - MikroC PRO for PIC v6.5.0
 *   - MikroC PRO for PIC32 v3.5.0
 *
 * SPI pins:
 *   RF13 = SCK (pin 39)
 *   RF4 = SDI (pin 49)
 *   RF5 = SDO (pin 50)
 *
 * Note:
 *  - _SPI_HIGH_2_LOW in MikroC PRO for PIC equals_SPI_ACTIVE_2_IDLE in
 *    MikroC PRO for PIC32
 *  - Data sent through SPI is displayed on PORTD
 *  - PIC32 SPI is 5v tolerant so no voltage conversion is needed between a
 *    PIC18F and a PIC32.
 */
unsigned short state=0;

void main() {
  //Visualise output on port D
  TRISD = 0;
  PORTD = 0;

  SPI1_Init_Advanced(
    _SPI_MASTER_OSC_DIV64,
    _SPI_DATA_SAMPLE_MIDDLE,
    _SPI_CLK_IDLE_LOW,
    _SPI_HIGH_2_LOW
  );
  
  while(1){
    SPI1_write(state);
    PORTD = state;
    state++;
    delay_ms(200);
  }
}